@@ -107,7 +107,7 @@ on_album_artist_focus_out_event        (GtkWidget       *widget,
         fatalError("malloc(sizeof(gchar) * (strlen(ctext) + 1)) failed. Out of memory.");
     strncpy(text, ctext, strlen(ctext)+1);
     
-    //trim_chars(text, BADCHARS);		// lnr	//Commented out by mrpl
+    //trim_chars(text, BADCHARS);        // lnr    //Commented out by mrpl
     trim_whitespace(text);
     
     if(text[0] == '\0')
@@ -154,7 +154,7 @@ on_album_title_focus_out_event         (GtkWidget       *widget,
         fatalError("malloc(sizeof(gchar) * (strlen(ctext) + 1)) failed. Out of memory.");
     strncpy(text, ctext, strlen(ctext)+1);
     
-    //trim_chars(text, BADCHARS);		// lnr	//Commented out by mrpl
+    //trim_chars(text, BADCHARS);        // lnr    //Commented out by mrpl
     trim_whitespace(text);
     
     if(text[0] == '\0')
@@ -181,7 +181,7 @@ on_album_genre_focus_out_event         (GtkWidget       *widget,
 
     strncpy(text, ctext, strlen(ctext)+1);
     
-    //trim_chars(text, BADCHARS);		// lnr	//Commented out by mrpl
+    //trim_chars(text, BADCHARS);        // lnr    //Commented out by mrpl
     trim_whitespace(text);
     
     if(text[0] == '\0')
@@ -241,7 +241,7 @@ on_artist_edited                    (GtkCellRendererText *cell,
                     GTK_TREE_VIEW(lookup_widget(win_main, "tracklist"))));
     GtkTreeIter iter;
     
-    //trim_chars(new_text, BADCHARS);		// lnr	//Commented out by mrpl
+    //trim_chars(new_text, BADCHARS);        // lnr    //Commented out by mrpl
     trim_whitespace(new_text);
     
     gtk_tree_model_get_iter_from_string(GTK_TREE_MODEL(store), &iter, path_string);
@@ -495,19 +495,19 @@ on_edit_split_clicked (void)
 
         if (riptrack)       // Only modify selected tracks
         {
-            char *slash = strchr(tracktitle, '/');
-            if (slash != NULL)
+            char *separator = strchr(tracktitle, global_prefs->concatenated_track_separator[0]);
+            if (separator != NULL)
             {
-                // If slash is present, split Artist/Title
+                // If separator is present, split Artist/Title
                 trackartist = strdup(tracktitle);
-                slash = strchr(trackartist, '/');
-                char *cp = slash + 1;
-                while (*cp && isspace(*cp))     // Remove space after slash
-                    ++cp;
+                separator = strchr(trackartist, global_prefs->concatenated_track_separator[0]);
+                char* cp = separator + 1;
+                while (*cp != '\0' && isspace(*cp))     // Remove space after separator
+                    cp++;
                 strcpy(tracktitle, cp);
-                *slash = '\0';
-                cp = slash - 1;
-                while (cp >= trackartist && *cp && isspace(*cp))     // Remove space before slash
+                *separator = '\0';
+                cp = separator - 1;
+                while (cp >= trackartist && *cp && isspace(*cp))     // Remove space before separator
                 {
                     *cp = '\0';
                     cp--;
@@ -530,6 +530,79 @@ on_edit_split_clicked (void)
     }
 }
 
+static void
+concatenate_artist_track(void)
+{
+    GtkTreeIter iter;
+    GtkListStore* store = GTK_LIST_STORE(gtk_tree_view_get_model(
+                          GTK_TREE_VIEW(lookup_widget(win_main, "tracklist"))));
+    
+    gboolean valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(store), &iter);
+    
+    while(valid)
+    {
+        GValue gTitle = {0, };
+        gtk_tree_model_get_value(GTK_TREE_MODEL(store), &iter, COL_TRACKTITLE,
+                &gTitle);
+        const char* title = g_value_get_string(&gTitle);
+        
+        GValue gArtist = {0, };
+        gtk_tree_model_get_value(GTK_TREE_MODEL(store), &iter, COL_TRACKARTIST,
+                &gArtist);
+        const char* artist = g_value_get_string(&gArtist);
+        
+        char separator[] = {"   "};
+        separator[1] = global_prefs->concatenated_track_separator[0];
+        
+        char* artist_and_track = malloc(strlen(artist)
+                                        + strlen(title)
+                                        + strlen(separator) + 1);
+        
+        if(!artist_and_track)
+        {
+            fatalError("malloc(strlen(artist)+strlen(title)+strlen(separator)+1)"
+                       " failed. Out of memory");
+        }
+        
+        artist_and_track[0] = '\0';
+        strcat(artist_and_track, artist);
+        strcat(artist_and_track, separator);
+        strcat(artist_and_track, title);
+        
+        gtk_list_store_set(store, &iter, COL_TRACKARTISTTITLE, artist_and_track, -1);
+        
+        free(artist_and_track);
+        
+        valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(store), &iter);
+    }
+}
+
+static void
+toggle_joined_title_artist                      (void)
+{
+    if(join_artist_title <= JOIN_OFF)
+    {
+        concatenate_artist_track();
+        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lookup_widget(win_main,
+                        "single_artist")), TRUE);
+        join_artist_title = JOIN_ON;
+    }
+    else
+    {
+        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lookup_widget(win_main,
+                        "single_artist")), FALSE);
+        join_artist_title = JOIN_OFF;
+    }
+
+    GtkTreeViewColumn * concatenatedCol = gtk_tree_view_get_column(
+            GTK_TREE_VIEW(tracklist), COL_TRACKARTISTTITLE);
+    gtk_tree_view_column_set_visible(concatenatedCol, join_artist_title == JOIN_ON);
+
+    GtkTreeViewColumn * titleCol = gtk_tree_view_get_column(GTK_TREE_VIEW(tracklist),
+            COL_TRACKTITLE );
+    gtk_tree_view_column_set_visible(titleCol, join_artist_title == JOIN_OFF);
+}
+
 void
 on_edit_swap_clicked (void)
 {
@@ -868,11 +941,13 @@ void
 on_single_artist_toggled               (GtkToggleButton *togglebutton,
                                         gpointer         user_data)
 {
-//    GtkTreeViewColumn * col = gtk_tree_view_get_column(GTK_TREE_VIEW(tracklist), 2);
-    GtkTreeViewColumn * col = gtk_tree_view_get_column(GTK_TREE_VIEW(tracklist), COL_TRACKARTIST ); //lnr
-    gtk_tree_view_column_set_visible(col, !gtk_toggle_button_get_active(togglebutton));
+    GtkTreeViewColumn * artistCol = gtk_tree_view_get_column(GTK_TREE_VIEW(tracklist),
+            COL_TRACKARTIST ); //lnr
+    gtk_tree_view_column_set_visible(artistCol,
+            !gtk_toggle_button_get_active(togglebutton));
 }
 
+// lnr
 void
 on_title_edited                    (GtkCellRendererText *cell,
                                     gchar               *path_string,
@@ -883,7 +958,7 @@ on_title_edited                    (GtkCellRendererText *cell,
                     GTK_TREE_VIEW(lookup_widget(win_main, "tracklist"))));
     GtkTreeIter iter;
     
-    //trim_chars(new_text, BADCHARS);		// lnr	//Commented out by mrpl
+    //trim_chars(new_text, BADCHARS);        // lnr    //Commented out by mrpl
     trim_whitespace(new_text);
     
     gtk_tree_model_get_iter_from_string(GTK_TREE_MODEL(store), &iter, path_string);
@@ -927,18 +1002,36 @@ on_tracklist_mouse_click               (GtkWidget* treeView,
         gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuItem);
         gtk_widget_show_all(menu);
 
-        menuItem = gtk_menu_item_new_with_label(_("Split 'Artist/Title' in Title field"));
+        const char splitTemplate[] = "Split 'Artist%cTitle' in Title field";
+        char splitLabel[sizeof(splitTemplate)];
+        sprintf(splitLabel, splitTemplate, global_prefs->concatenated_track_separator[0]);
+
+        if(join_artist_title == JOIN_UNSET)
+        {
+            menuItem = gtk_menu_item_new_with_label(_(splitLabel));
+            g_signal_connect(menuItem, "activate",
+                             G_CALLBACK(on_edit_split_clicked), NULL);
+            gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuItem);
+            gtk_widget_show_all(menu);
+        }
+
+        const char joinTemplate[] = "Join 'Artist%cTitle' in Title field";
+        char joinLabel[sizeof(joinTemplate)];
+        sprintf(joinLabel, joinTemplate, global_prefs->concatenated_track_separator[0]);
+
+        menuItem = gtk_menu_item_new_with_label(_(
+            join_artist_title == JOIN_ON ? splitLabel : joinLabel));
         g_signal_connect(menuItem, "activate",
-                         G_CALLBACK(on_edit_split_clicked), NULL);
+                         G_CALLBACK(toggle_joined_title_artist), NULL);
         gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuItem);
         gtk_widget_show_all(menu);
-
+        
         menuItem = gtk_menu_item_new_with_label(_("Swap Artist <=> Title"));
         g_signal_connect(menuItem, "activate",
                          G_CALLBACK(on_edit_swap_clicked), NULL);
         gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuItem);
         gtk_widget_show_all(menu);
-        
+
         gtk_menu_popup(GTK_MENU(menu), NULL, NULL, NULL, NULL,
                        event->button, gdk_event_get_time((GdkEvent*)event));
         
