@@ -26,6 +26,8 @@ void
 on_aboutbox_response                   (GtkDialog       *dialog,
                                         gint             response_id,
                                         gpointer         user_data);
+void
+update_track_offsets                   (void);
 
 gboolean
 on_album_artist_focus_out_event        (GtkWidget       *widget,
@@ -48,6 +50,15 @@ on_album_genre_focus_out_event         (GtkWidget       *widget,
                                         GdkEventFocus   *event,
                                         gpointer         user_data);
 
+gboolean
+on_tracknum_first_focus_out_event      (GtkWidget       *widget,
+                                        GdkEventFocus   *event,
+                                        gpointer         user_data);
+
+void
+on_tracknum_width_changed_event        (GtkComboBox     *combobox,
+                                        gpointer         user_data);
+
 void
 on_artist_edited                    (GtkCellRendererText *cell,
                                      gchar               *path_string,
@@ -90,6 +101,10 @@ void
 on_mp3bitrate_value_changed            (GtkRange        *range,
                                         gpointer         user_data);
 
+void
+on_fdkaac_bitrate_value_changed            (GtkRange        *range,
+                                        gpointer         user_data);
+
 void
 on_opusrate_value_changed               (GtkRange       *range,
                                          gpointer        user_data);
@@ -152,15 +167,16 @@ on_rip_flac_toggled                    (GtkToggleButton *togglebutton,
 void
 on_rip_mp3_toggled                     (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
+
+void
+on_rip_fdkaac_toggled                     (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
                                         
 void
 on_rip_wavpack_toggled                 (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
 void
 on_rip_monkey_toggled                  (GtkToggleButton *togglebutton,
-                                        gpointer         user_data);
-void
-on_rip_aac_toggled                  (GtkToggleButton *togglebutton,
                                      gpointer         user_data);
 void
 on_rip_musepack_toggled                  (GtkToggleButton *togglebutton,
