@@ -1083,6 +1083,7 @@ create_prefs (void)
     GtkWidget* serverName;
     GtkWidget* portNum;
     GtkWidget* frameVbox;
+    GtkWidget* concatenated_track_separator;
     GtkWidget* do_log;
     GtkWidget* do_fast_rip;
     
@@ -1176,6 +1177,30 @@ create_prefs (void)
     gtk_widget_show (portNum);
     gtk_box_pack_start (GTK_BOX (hbox), portNum, TRUE, TRUE, 5);
     GLADE_HOOKUP_OBJECT (prefs, portNum, "port_number");
+
+    frame = gtk_frame_new (NULL);
+    gtk_widget_show (frame);
+    gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE, 0);
+    gtk_frame_set_label(GTK_FRAME(frame), "Right-click options");
+    
+    frameVbox = gtk_vbox_new (FALSE, 0);
+    gtk_widget_show (frameVbox);
+    gtk_container_add (GTK_CONTAINER (frame), frameVbox);
+    
+    hbox = gtk_hbox_new (FALSE, 0);
+    gtk_widget_show (hbox);
+    gtk_box_pack_start (GTK_BOX (frameVbox), hbox, FALSE, FALSE, 1);
+    
+    label = gtk_label_new (_("Artist/Title separator: "));
+    gtk_widget_show (label);
+    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 5);
+ 
+    concatenated_track_separator = gtk_entry_new();
+    gtk_entry_set_max_length(GTK_ENTRY(concatenated_track_separator), 1);
+    gtk_widget_show(concatenated_track_separator);
+    gtk_box_pack_start (GTK_BOX (hbox), concatenated_track_separator, TRUE, TRUE, 5);
+    GLADE_HOOKUP_OBJECT (prefs, concatenated_track_separator,
+            "concatenated_track_separator");
     
     do_log = gtk_check_button_new_with_label (_("Log to /var/log/asunder.log"));
     gtk_widget_show (do_log);
@@ -1524,7 +1549,7 @@ toggle_allow_tracknum(void)
 }
 
 const char* 
-GBLprogramName = "Asunder 2.9.3";
+GBLprogramName = "Asunder 2.9.5";
 
 static const char* 
 GBLauthors[2] = {
@@ -1532,7 +1557,7 @@ GBLauthors[2] = {
 "\n"
 "Andrew Smith\n"
 "http://littlesvr.ca/contact.php\n"
-"2005 - 2018\n"
+"2005 - 2019\n"
 "- maintainer\n"
 "\n"
 "Eric Lathrop\n"
@@ -1619,6 +1644,9 @@ GBLauthors[2] = {
 "Antony Gelberg\n"
 "- Fixed when the CD is ejected to avoid problems before a full rip/encode cycle is completed.\n"
 "\n"
+"Tom Bailey\n"
+"- Added support for joining artist and title in title field.\n"
+"\n"
 "Packages:\n"
 "\n"
 "Toni Graffy\n"
@@ -1700,7 +1728,7 @@ GBLtranslators =
 "- ca (Catalan) translation of Asunder versions 0.8.1 - 1.9\n"
 "\n"
 "Toni Estevez\n"
-"- ca (Catalan) translation of Asunder version 2.8\n"
+"- ca (Catalan) translation of Asunder versions 2.8 - 2.9.5\n"
 "\n"
 "Schmaki\n"
 "- cs (Czeck) translation of Asunder versions 0.8 - 1.0, 1.9\n"
@@ -1744,6 +1772,9 @@ GBLtranslators =
 "Eero Salokannel\n"
 "- fi (Finnish) translation of Asunder versions 0.8 - 2.2\n"
 "\n"
+"janikinnunen\n"
+"- fi (Finnish) translation of Asunder versions 2.9.3\n"
+"\n"
 "Christophe Legras\n"
 "- fr (French) translation of Asunder versions 0.8 - 1.9\n"
 "\n"
@@ -1896,7 +1927,7 @@ N_("An application to save tracks from an Audio CD \n"
 static const char* 
 GBLcopyright = 
 "Copyright 2005 Eric Lathrop\n"
-"Copyright 2007 - 2018 Andrew Smith";
+"Copyright 2007 - 2019 Andrew Smith";
 
 static const char* 
 GBLwebsite = "http://littlesvr.ca/asunder/";
