@@ -12,6 +12,7 @@ enum
     COL_TRACKNUM_VIS,
     COL_TRACKARTIST,
     COL_TRACKTITLE,
+    COL_TRACKARTISTTITLE,
     COL_TRACKTIME,
     NUM_COLS
 };
@@ -44,4 +45,13 @@ extern GtkWidget * tracklist;
 
 extern int gbl_null_fd;
 
+typedef enum JoinState
+{
+    JOIN_UNSET,
+    JOIN_OFF,
+    JOIN_ON
+} JoinState;
+
+extern JoinState join_artist_title;
+
 //#define DEBUG
